---
authors:
  - Tim
  - Jane
  - Sally
owner: Joe
valid:
  from: 2020-01-01
  to: 2099-12-31
x-trestle-template-type: architecture
---

# System architecture

Here is some content

## Overview

And some more

## Security model

And even more
